Implementation of SQPnP perspective-n-point algorithm.
This can be used to determine the pose of a 3D object given two sets of corresponding points: a set of 3D points from the object and a set of 2D projected points (often from an image).
See the C++ implementation for more information about SQPnP: terzakig/sqpnp.
Structs
- Default
Parameters - Default parameters for the SQPnP algorithm.
- Solution
- A possible PnP solution.
- Solver
- A SQPnP solver.
Traits
- Parameters
- Parameters used by the SQPnP algorithm.
Functions
- eigen_
vectors_ rrqr - Generate Eigen vectors, and initial Eigen values given the omega matrix, using QR decomposition.
- eigen_
vectors_ svd - Generate Eigen vectors, and initial Eigen values given the omega matrix, using SVD.
- nearest_
rotation_ matrix_ foam - Calculate the nearest rotation matrix to
musing an algorithm derived from the FOAM algorithm. - nearest_
rotation_ matrix_ svd - Calculate the nearest rotation matrix to
musing SVD.